#
# private Mails
#

:0
* ^From.*(thorsten@ankh\.ping\.de |\
	TRedicker@lp-software\.de |\
	vordenw@uni-muenster\.de |\
	HELGE_CLAUSSEN.* |\
	Marcus\.Stark@Materna\.DE |\
	WSchoebe@aol\.com |\
	AlbertPaas@t-online\.de |\
	Binegross@aol\.com |\
	mvoskors@ncc\.de |\
	Stefan_Mueller@mk2\.maus\.sauerland\.de |\
	dirk@obelix\.ping\.de|\
	romuald@cww\.de |\
	lars@vergil\.ping\.de|\
	rloebbe@fasta\.fh-dortmund\.de|\
	manroe@manki\.toppoint\.de|\
	utevdw@rhw\.uni-muenster\.de|\
	su0208@sx2\.HRZ\.Uni-Dortmund\.DE|\
	valentin\.weiske@mbv\.tu-chemnitz.de|\
	Mueller@leu03222\.test\.uunet\.de|\
	smm@rentrop2\.bn\.uunet\.de|\
	Kahl_Lars@hre\.krupp\.com|\
	s10314@sb\.hhs\.dk|\
	TRedicker@medwork\.de|\
	Alexandrina\.Neves\.Pinheiro@do\.quantum\.de)
| appnmail $MAILDIR/Privat.mbox

#
# alles, was an BlackBox geht, ist auch privat.
#
:0
* ^TO.*BlackBox@vergil\.ping\.de
| appnmail $MAILDIR/Privat.mbox

:0
* ^TO.*next-club-schwerte@vergil\.ping\.de
| appnmail $MAILDIR/Privat.mbox

#
# mails an die Beng Mailing liste aussortieren
#
:0
* ^TO.*beng@buran\.fb10\.tu-berlin\.de
| appnmail $MAILDIR/BENG.mbox

:0
* ^TO.*next_readmes@prz\.tu-berlin\.de
| appnmail $MAILDIR/BENG.mbox

:0
* ^TO.*BeNG-Ankuendigung@stepman\.com
| appnmail $MAILDIR/BENG.mbox

:0
* ^TO.*beng@beng\.org
| appnmail $MAILDIR/BENG.mbox

:0
* ^TO.*beng-announce@beng\.org
| appnmail $MAILDIR/BENG.mbox
