#
# Anstatt vacation kann man auch diese rc mittels INCLUDERC einbauen. Die
# bewirkt dann das gleiche wie Vacation, jedoch geht der gute alte Procmail
# Mechanismus nicht verloren.

SHELL=/bin/sh
SENDMAIL=/usr/lib/sendmail	# remember: sendmail auf jeanine
VERBOSE=off

:0
* !^FROM_DAEMON
* !^From +dirk@object-factory\.com
{
	FROM=`formail -rx To:`
	ALREADYSENT=$HOME/vacation     # the  vacation data-base
	
	:0 c:                       # the lockfile is important	
	* !? /usr/local/bin/grep -iq $FROM $ALREADYSENT
	| echo $FROM >> $ALREADYSENT; \
	(formail -rA"Precedence: junk"; \
		cat $HOME/.vacation.msg; \
		echo "-- "; cat $HOME/.signature \
	) | $SENDMAIL -t 
}

#
# waehrend der Ferien alle Failure Notices getrennt sammeln ...
#
:0
* ^FROM_DAEMON.*
* Subject.*failure notice.*
| appnmail $MAILDIR/FailureNotice.mbox

#
# Waehrend der Ferien brauche ich auch keine Nachrichten ueber Essenbestellungen
#
:0
* ^TO of_catering@object-factory\.com
/dev/null

:0
* ^TO catering@object-factory\.com
/dev/null
 