#                     THE SPAM BOUNCER
#                     Version 0.9t beta
#
#      Copyright (C) 1996, 1997 by Catherine A. Hampton.  If 
#      you abide by the Free Software Foundation's COPYING 
#      principles with this document, you're home free, but 
#      don't try to copyright it yourself or sell this 
#      information.
#
#  Installation instructions can be retrieved at:
#            http://www.best.com/~ariel/nospam/
#
# THE NOBOUNCE FILE
#    This is a file of addresses of friends and others you 
#    want to get mail from, but who are at spam haven
#    domains/systems.  This way, they can mail you without
#    trouble, even if your filter drops all other mail from 
#    that site.
#:1
#? fgrep -i -f $HOME/nobounce
#$DEFAULT

# BOUNCE FILE
#    This file contains addresses and domains with no legitimate
#    users -- known spammers and spam domains only.  I have it
#    set to make a backup copy of the spam and then bounce the
#    spam with a "User Unknown" error, in hopes that spammers
#    will get frustrated and remove my address, and your addresses,
#    from their lists. :)

SPAMLIST=$HOME/spam.messages

# ISP Inter.net <GRRRRRRR>
:0
* ^(From.|Reply-To:|Message-ID:|Received:).*[^0-9A-Za-z](206\.154\.151|\
        isp-inter\.net|\
		juno\.com|\
        Infinity@.*1starnet\.com|\
        KINGofINK@aol\.com|\
        Venustar@1starnet\.com|\
		twalker@32846\.net|\
		investigations17\.comx@lsbsdi1\.lightspeed\.net|\
		bnd2bfre@ix\.gen\.com|\
		The\.Card\.2\.Have@uumx\.smtp\.psi\.net|\
		humor@powertips\.com|\
		dover@pop\.dti\.net|\
		crime@tarsey\.com|\
		computermas@aol\.com|\
		800@tollfree\.net|\
		mck@epislonfree\.com|\
		suzi@upsouth\.com|\
		x-toys@adv\.com|\
		earthlink\.net|\
		rudae@gosnet\.com|\
		just4u2911@netzone\.com|\
		savetrees\.com|\
		emailblaster@mail-response\.com|\
		que11331236@compuserve\.com|\
		sbliss@earthfriends\.com|\
		taceeqi@bizproplus\.com|\
		60210891@alaska\.net|\
		77061904@aol\.com|\
		t3@t3-com\.com|\
		yourfriend@tele\.ntnu\.no|\
		worldnet\.att\.net|\
		eclark1@power-agents\.com|\
		OnlyTheBest@aaanews\.com|\
		18330444@msn\.com|\
		sand@flea\.com|\
		ix\.netcom\.com|\
		breakth@breakthruint\.com|\
		emailing@tnlb\.com|\
		all_friends@the_third_pla\.net|\
		msc1@qualhost\.com|\
		pnwood@earth\.we-deliver\.net|\
		info@cyperinfo\.com|\
		yourcredit@westcoastmemory\.com|\
		pape60@cajones\.com|\
		niki25a127@prodigy\.com|\
		roy76@mandex\.com|\
		81697049@msn\.com|\
		gai4@aol\.com|\
		billy@bingo\.edu|\
		rem@bizzy\.net|\
		duwi27@calvacom\.fr|\
		kimmi@4integrity\.com|\
		99001680@msn\.com|\
		webtech@mmaildirect\.com|\
		Success@www.kse\.or\.kr|\
		biwupo58@netcom\.com|\
		*@global-ads\.com|\
		starfish@xausfam\.riser\.net|\
		user0105@mallmaster1\.com|\
		kysomail@venus\.gmds\.com|\
		ken@online-success\.com|\
		Visit_Our_Site@SendAd\.com|\
		654932221@nickel\.net|\
		makingmusic@olma\.net|\
		qadionu98@birch\.de|\
		mis-mail\.com|\
		betterlife@1daystar\.com|\
		email101@daltek\.net|\
		38243125@aol\.com|\
		mentor@mail\.bip\.net|\
		qeceo76@anion\.epita\.fr|\
		\(Floodgate\)|\
		ronnie@iamerica\.net|\
		plasticcombs\.com|\
		VR972411BT@aol\.com|\
		nimark@mailexcite\.com|\
		rao@oulu\.fi|\
		bways@earth\.spearhead\.net|\
		vpros@vpros\.com|\
		happy@mlmail\.com|\
		return@mail2\.vspn\.net|\
		highjock@yahoo\.com|\
		analysis@MortgageCity\.com|\
		newsletter@pinanet\.net|\
		y8L5HEt9w@lycosemail\.com|\
		apex5@gte\.net|\
		t3@t3mailer\.com|\
		87334685@aol\.com|\
		fikua41@versant\.de|\
		hk\.super\.net|\
		97324682@aol\.com|\
		Eng500@aol\.com|\
		Ekkoh1@aol\.com|\
		putpeel@putpeel\.com|\
		make004@aoll\.com|\
		yummies@webbdirect\.com|\
		jasmine@webbdirect\.com|\
		savefuel@bellsouth\.net|\
		AmazingSecrets@WorldInner\.Circle|\
		merchant25@apmail\.com|\
		heiwoi88@mail@plus\.it|\
		moneytime@aol\.com|\
		Lifestyle@StarInvest\.com|\
		sales@sportstrax\.com|\
		daore10@msn\.com|\
		kerry\.rex@pacbell\.net|\
		liy89@prodigy\.com|\
		cea90@aol\.com|\
		promo@pro\.net|\
		2sw722@att\.net|\
		response@jetclass\.com|\
		naukei81@mithchel22@msn\.com|\
		corvett52@yahoo\.com|\
		georgia\.walters@pemail\.net|\
		reply@123bizweb\.com|\
		softwarecenter@goplay\.com|\
		Megan3826@rt66\.com|\
		truedream20@lycosmail\.com|\
		UnitedWF@linxzit\.net|\
		roa223@intouchtelecom\.com|\
		LVLOVE@aol\.com|\
		JADUNLAPJR@aol\.com|\
		moneyhelp@mymail\.com|\
		d-int@ccr\.net|\
		suu97@msn\.com|\
		awy@canyonsales\.com|\
		adjhe@mailcity\.com|\
		lhto@euronet\.nl|\
		rir@atnet\.at|\
		marketnewstoday11_24_98iilli@psi\.net|\
		dachitwood@cooptech\.com|\
		blade_runner2@excite\.com|\
		863610@coolmail\.com|\
		fe1e@msn\.com|\
		za@fz\.ml\.org|\
		ciree8ek@rubikon\.net\.pl|\
		trythis@asiancityweb\.com|\
		Trcyalk@ibm\.net|\
		internettips@hotbot\.com|\
		homebus@hamkk\.fi|\
		*@calu99\.net|\
		hmwp@msn\.com |\
		mark6751@youpy.com |\
		oboausdyra@turbomail\.net|\
		freegift@mailcity\.com|\
		wealth4you@adexec\.com|\
		newyou@mailcty\.com|\
		*@yes\.zzn\.com|\
		support@egroups\.net)
* !^X-Loop: noloop@noloop.nlp
$SPAMFOLDER

#
# dirk Test
#
:0
* X-1.*This email was sent by "Cyber-Bomber"
$SPAMFOLDER

:0
* From:.*autoresponder@gmx\.net
$SPAMFOLDER

:0
* To:.*Friend@public\.com.*
$SPAMFOLDER

:0
* X-Advertisement.*
$SPAMFOLDER

# Spamford <GRRRRRRRRRR!!!>
:0
* ^(From.|Reply-To:|Message-ID:|Received:).*[^0-9A-Za-z](206\.27\.86|\
            208\.9\.64|\
            1stamend\.com|\
            answerme\.com|\
            acun\.com|\
            \.cpbw[^0-9A-Za-z]|\
            bndwdth\.prtnr|\
            bu1kemai1\.com|\
            bulkads\.com|\
            bulkinquiries\.com|\
            bulkinternet\.com|\
            bulkmagnet\.com|\
            bulkpower\.com|\
            bulkreadit\.com|\
            bulkresponses\.com|\
            bulkseeit\.com|\
            bulksendit\.com|\
            cyber-l-i-1\.com|\
            cyber-o-0-o\.com|\
            cyber-promo\.com|\
            cyber-t-p-l\.com|\
            cyberemag\.com|\
            cyberout\.com|\
            cyberpr[o0]m[o0]\.com|\
            cyberpr[o0]m[o0]ti[o0]ns\.com|\
            emai[1l]2u\.com|\
            emai[1l]srus\.com|\
            email2you\.com|\
            emailsrus\.com|\
            fight4rights\.com|\
            freeconnect\.com|\
            gohomeray\.com|\
            hereyougo\.com|\
            internetfree\.com|\
            mailreport\.com|\
            manybiz\.com|\
            massemail\.com|\
            massmarket\.com|\
            noblock\.com|\
            nocensorship\.com|\
            nostoppingittop[^0-9A-Za-z]|\
            pleaseread\.com|\
            promocyber\.com|\
            randomdomain\.com|\
            reedrules\.com|\
            sanfordw\.com|\
            savepaper\.com|\
            savetrees\.com|\
            sendasong2u\.com|\
            sender3\.com|\
            stoptheblock\.com|\
            swallace\.com|\
            yougotmail\.com|\
            youvegotmail\.com|\
            cyberout@.*|\
            cyberpr@.*|\
			Postal@Mail\.Below\.*|\
			best@computer\.prices\.com|\
			approved!@guaranteed-approval\.com|\
			coebe9@mci\.net)
* !^X-Loop: noloop@noloop.nlp
$SPAMFOLDER

# Sallynet/Nancynet & Company
:0
* ^(From.|Reply-To:|Message-ID:|Received:).*[^0-9A-Za-z](208\.1\.117|\
        internet-income\.com|\
        liame\.com|\
        nancynet\.com|\
        ponypress\.com|\
        rescueinfo\.com|\
        sallynet\.com|\
        tech-shop\.com|\
		mail\.vdocam\.com)
* !^X-Loop: noloop@noloop.nlp
$SPAMFOLDER

# IQ-Internet
:0
* ^(From.|Reply-To:|Message-ID:|Received:).*[^0-9A-Za-z](208\.8\.32|\
                 208\.8\.33|\
                 208\.8\.34|\
                 208\.8\.35|\
                 208\.8\.36|\
                 208\.8\.37|\
                 208\.8\.38|\
                 208\.8\.39|\
                iq-internet\.)
* !^X-Loop: noloop@noloop.nlp
$SPAMFOLDER

# Camelot/AGIS Spam
:0
* ^(From.|Reply-To:|Message-ID:|Received:).*([^0-9A-Za-z]camelot\.net|\
              [^0-9A-Za-z]damsel\.com|\
              [^0-9A-Za-z]davenda\.com|\
              [^0-9A-Za-z]honeys\.com|\
              [^0-9A-Za-z]hotgrrls\.com|\
              [^0-9A-Za-z]hunkview\.com|\
              [^0-9A-Za-z]luv2cu\.com|\
              [^0-9A-Za-z]overtheair\.com|\
              [^0-9A-Za-z]rosepin\.com|\
              [^0-9A-Za-z]seductress\.com|\
              [^0-9A-Za-z]seemen\.com|\
              [^0-9A-Za-z]sensuousexotics\.com|\
              [^0-9A-Za-z]studline\.com|\
              [^0-9A-Za-z]sweeties\.com|\
              [0-9A-Za-z]*4u\.com)
* !^X-Loop: noloop@noloop.nlp
$SPAMFOLDER

# "Seductress" spam
:0
* ^(From.|Reply-To:|Message-ID:|Received:).*[^0-9A-Za-z](208\.1\.232\.|\
        mandy\.com|\
        rasha\.com|\
        seductress\.com|\
        xzy[^0-9A-Za-z])
* !^X-Loop: noloop@noloop.nlp
$SPAMFOLDER

# Death Star
:0
* ^(From.|Reply-To:|Message-ID:|Received:).*[^0-9A-Za-z](206\.154\.39|\
        death-star\.com)
* !^X-Loop: noloop@noloop.nlp
$SPAMFOLDER

# General Sprint Spam
:0
* ^(From.|Reply-To:|Message-ID:|Received:).*[^0-9A-Za-z](208\.1\.232\.102|\
        mandy\.com|\
        morefreestuff\.com|\
        rasha\.com |\
		clover@earthfriends\.com)
$SPAMFOLDER

# General MCI Spam
:0
* ^(From.|Reply-To:|Message-ID:|Received:).*[^0-9A-Za-z](204\.163\.210|\
        globalfinc\.com|\
        1stchoice\.com)
$SPAMFOLDER

# General AGIS Spam
:0
* ^(From.|Reply-To:|Message-ID:|Received:).*[^0-9A-Za-z](207\.179\.2\.249|\
        omnisolve\.com)
$SPAMFOLDER

# General Spam
:0
* ^(From.|Reply-To:|Message-ID:|Received:).*[^0-9A-Za-z](204\.188\.141|\
        add-url\.com|\
        admail|\
        allvip\.com|\
        enterprise\.america\.com|\
        aperfect10\.com|\
        arvon-usa\.com|\
        aviusa\.com|\
        bigprofits\.com|\
        bbbiiizzz|\
        beyonddotcom\.com|\
        bizimage\.com|\
        bretsvettes\.com|\
        brobro\.com|\
        bulk-e-mail\.com|\
        californiakid\.com|\
        capella\.net|\
        chag\.com|\
        clever\.net|\
        cmestrip\.com|\
        cn\.com|\
        cockring\.com|\
        codecracker\.com|\
        crownwell\.com|\
        cyberonline\.com|\
        cyberramp\.com|\
        cybersell|\
        cybershopclub\.com|\
        cyberspace\.com|\
        cyber?times\.com|\
        cyber?times\.org|\
        djgroup\.com|\
        dm1\.com|\
        dutch-delight\.nl|\
        emaster\.com|\
        exhibitionists\.com|\
        fincon\.com|\
        flixxx|\
        free-speach\.net|\
        freestuff4u\.com|\
        freeview\.com|\
        getrich\.com|\
        girlickers\.com|\
        girlstodiefor\.com|\
        globalfn\.com|\
        golfballsunlimitedusa\.com|\
        hardview\.com|\
        helpnet|\
        hereyougo\.com|\
        hotstrip\.com|\
        hunkview\.com|\
        ibb[)\. ]|\
        infi-pos\.com|\
        imago\.net|\
        infofree\.com|\
        inteam\.com|\
        internetfleamarket\.com|\
        intimatedesires\.com|\
        itouchmyself\.com|\
        ivpb\.com|\
        l-e-n|\
        lettucepatch\.com|\
        light-avenue\.com|\
        livekinkysex\.com|\
        loop\.(com|net)|\
        magazineclub|\
        mailloop\.com|\
        massmail\.com|\
        megabytecoffee\.com|\
        mjcl\.com|\
        moneyworld|\
        mremail\.com|\
        nakedfashion\.com|\
        natmed\.com|\
        natureplus|\
        nookylooky\.com|\
        ntview\.com|\
        ntz\.com|\
        nymphsrus\.com|\
        one-and-only\.com|\
        outmail.*|\
        party\.com|\
        pdwsi\.com|\
        peepshow\.com|\
        perkybreasts\.com|\
        phazer\.com|\
        ppgsoft[^0-9A-Za-z]|\
        primepussy\.com|\
        pwrnet\.com|\
        rapidvend\.com|\
        resultnet\.com|\
        ring\.com|\
        seemen\.com|\
        seemestrip\.com|\
        selfhelpnet\.com|\
        seriousincome\.com|\
        servint|\
        sexysearch\.com|\
        sfdungeon\.com|\
        sftcell|\
        shoppingplanet|\
        smutmail\.com|\
        snappy\.com|\
        softcell\.(com|net)|\
        SoftCell\.Marketing\.Inc.*|\
        stratos\.net|\
        strutstuff\.com|\
        studline\.com|\
        subweb\.com|\
        supergood\.com|\
        sweet18\.com|\
        sweeties\.com|\
        sweinc\.com|\
        tara-helps\.com|\
        TheFinancialAlliance\.com|\
        themall\.net|\
        unidial\.com|\
        usa\.net|\
        vbox\.com|\
        videosecrets\.com|\
        virtual-adnet\.com|\
        voicenet\.com|\
        wallstreetweb\.com|\
        webcreations\.com|\
        webspinerz\.com|\
        westworld\.com|\
        wilshireblvd\.com|\
        xtremeradio\.com|\
        xtv\.com|\
        ynotu\.com|\
        youngirls\.com|\
        zilo\.com|\
        AlexE\.asf@worldnet\.att\.net|\
        bizwiz@.*remotemail\.com|\
        .*db@.*dalton\.net|\
        dareen@dallas\.com|\
        easy@easy\.com|\
        eureka@enterprise\.net|\
        [Ff]ull[Dd]ata[Bb]ase@.*|\
        gaa@iohk\.com|\
        julie@internichosting\.com|\
        kdlinfo@.*sprintmail\.com|\
        keroma@idt.net|\
        mfgtm@aol\.com|\
        [Mm]ass[Ee]mail.*@aol\.com|\
        naspa@internetmedia\.com|\
        rastalin@.*csionline\.com|\
        rcarter@.*usa\.net|\
        rcdana@.*cts\.com|\
        techrun@millennium\.millnet\.net|\
        tzachi@bestweb\.net|\
        zaptees@.*voicenet\.com)
* !^X-Loop: noloop@noloop.nlp
$SPAMFOLDER

:0
* ^X-Mailer: (.*Floodgate.*|\
              .*Extractor Pro.*|\
              .*Extractor Gold.*|\
              .*NetMailer.*)
* !^X-Loop: noloop@noloop.nlp
$SPAMFOLDER

:0
* ^Content-Type: Commercial E-Mail
* !^X-Loop: noloop@noloop.nlp
$SPAMFOLDER

:0
* ^Subject: M-Net Express
* ^X-Shocking-Site: http://www.cyberpromo.com
* !^X-Loop: noloop@noloop.nlp
$SPAMFOLDER

:0
* ^To: Friend@public\.com
* !^X-Loop: noloop@noloop.nlp
$SPAMFOLDER
